#!/usr/bin/python3

import threading
import managers.LinuxUserManager as LinuxUserManager
from datetime import datetime
import subprocess

LOG_FILE = "/var/log/eta-kisit.log"


def set_interval(func, sec):
    def func_wrapper():
        set_interval(func, sec)
        func()

    t = threading.Timer(sec, func_wrapper)
    t.start()
    return t


def print_log(msg):
    current_timestamp = datetime.now()
    log_msg = "[{}]: {}\n".format(current_timestamp, msg)

    with open(LOG_FILE, "a") as f:
        f.write(log_msg)

    print(log_msg)


try:
    last_active_session = LinuxUserManager.get_active_session_username()
except Exception as e:
    print_log("Exception on get_active_session: {}".format(e))


def check_active_session():
    global last_active_session

    try:
        active_session = LinuxUserManager.get_active_session_username()
    except Exception as e:
        print_log("Exception on get_active_session: {}".format(e))

    if active_session == "lightdm" or active_session == "Debian-gdm":
        active_session = None

    if last_active_session != active_session:
        # Session changed.
        if (
            active_session is not None
            and active_session != ""
            and active_session != "lightdm"
            and active_session != "Debian-gdm"
        ):
            print_log(
                "Active Session Changed: {} -> {}".format(
                    last_active_session, active_session
                )
            )
            try:
                subprocess.run(["eta-kisit", "--user-login", active_session])
            except Exception as e:
                print_log("Exception on eta-kisit --user-login call: {}".format(e))

        last_active_session = active_session


t = set_interval(check_active_session, 2)  # check every 2 seconds
t.join()
